@@ -42,6 +42,7 @@ class CursesMenu:
     :ivar normal: Index of the curses color pair used to represent other text
     :ivar items: The list of items for the menu
     :param show_exit_item: Whether the exit item is shown
+    :param zero_pad: Zero pad the item indices to match the width of the biggest one
     :ivar current_option: The index of the currently highlighted menu item
     :ivar selected_option: The index of the last item the user selected, initially -1
     :ivar should_exit: Flag to signal that the menu should exit on \
@@ -68,12 +69,15 @@ class CursesMenu:
         self,
         title: str = "",
         subtitle: str = "",
+        *,
         show_exit_item: bool = True,
+        zero_pad: bool = False,
         _debug_screens: bool = False,
-    ):
+    ) -> None:
         """Initialize the menu."""
         self.title = title
         self.subtitle = subtitle
+        self.zero_pad = zero_pad
 
         self.screen: Optional[Window] = None
 
@@ -116,7 +120,9 @@ class CursesMenu:
             },
         )
         # workaround for issue with windows-curses in vscode terminal
-        if os.environ.get("TERM_PROGRAM", default="") == "vscode":  # pragma: no cover
+        if (
+            os.environ.get("TERM_PROGRAM", default="") == "vscode"
+        ):  # pragma: no cover all
             self.user_input_handlers.update(
                 {
                     450: self.go_up,
@@ -129,16 +135,13 @@ class CursesMenu:
 
         self._debug_screens = _debug_screens
 
-    def __repr__(self) -> str:
-        """Get a string representation of the menu."""
-        return f"<{self.title}: {self.subtitle}. {len(self.items)} items>"
-
     @classmethod
     def make_selection_menu(
         cls,
         selections: List[str],
         title: str = "",
         subtitle: str = "",
+        *,
         show_exit_item: bool = False,
     ) -> "CursesMenu":
         """
@@ -218,7 +221,7 @@ class CursesMenu:
         if it's shown."""
         return len(self.all_items) - 1
 
-    def show(self) -> Any:
+    def show(self) -> Any:  # noqa: ANN401
         """
         Start the menu and blocks until it finishes.
 
@@ -254,11 +257,11 @@ class CursesMenu:
                 CursesMenu.stdscr = curses.initscr()
                 curses.noecho()
                 curses.cbreak()
-                CursesMenu.stdscr.keypad(True)
+                CursesMenu.stdscr.keypad(True)  # noqa: FBT003
                 # noinspection PyBroadException
                 try:
                     curses.start_color()
-                except:  # noqa: E722 # pragma: no cover
+                except:  # noqa: E722 # pragma: no cover all
                     pass
                 self._main_loop()
             finally:
@@ -266,7 +269,7 @@ class CursesMenu:
                 # should be None at runtime, so I'm leaving this as an if
                 # as opposed to an assert, but using a pragma for coverage
                 if CursesMenu.stdscr is not None:  # pragma: no branch
-                    CursesMenu.stdscr.keypad(False)
+                    CursesMenu.stdscr.keypad(False)  # noqa: FBT003
                 curses.endwin()
                 curses.echo()
                 curses.nocbreak()
@@ -308,7 +311,7 @@ class CursesMenu:
             self.draw_item(index, item)
 
         self.refresh_screen()
-        if self._debug_screens:  # pragma: no cover
+        if self._debug_screens:  # pragma: no cover all
             with open(
                 PROJECT_ROOT.joinpath("screendumps", f"{self.title}-{time.time()}"),
                 "wb",
@@ -338,6 +341,10 @@ class CursesMenu:
         """
         if index_text is None:
             index_text = str(index + 1)
+            if self.zero_pad:
+                pad_width = len(str(len(self.items)))
+                index_text = index_text.zfill(pad_width)
+
         text_style = self.highlight if self.current_option == index else self.normal
         assert self.screen is not None and text_style is not None
 
@@ -381,6 +388,14 @@ class CursesMenu:
         assert CursesMenu.stdscr is not None
         return CursesMenu.stdscr.getch()
 
+    def _exit(self) -> None:
+        self.should_exit = True
+
+    def _exit_with_return(self) -> int:
+        """Identical to _exit, but return in for type checking"""
+        self.should_exit = True
+        return 0
+
     def select(self, _: int = 0) -> None:
         """
         Select the current item.
@@ -403,9 +418,6 @@ class CursesMenu:
         if not self.should_exit:
             self.draw()
 
-    def _exit(self) -> None:
-        self.should_exit = True
-
     def go_to(self, user_input: int) -> None:
         """
         Go to a given numbered item.
@@ -470,7 +482,7 @@ class CursesMenu:
         self.screen.clear()
         self.refresh_screen()
 
-    def join(self, timeout: Optional[int] = None) -> Any:
+    def join(self, timeout: Optional[int] = None) -> Any:  # noqa: ANN401
         """
         Block until the menu exits.
 
@@ -513,7 +525,7 @@ class CursesMenu:
         """
         return self._main_thread.is_alive()
 
-    def exit(self, timeout: Optional[int] = None) -> Any:
+    def exit(self, timeout: Optional[int] = None) -> Any:  # noqa: A003, ANN401
         """
         Signal the menu to exit and block until it does.
 
@@ -535,3 +547,7 @@ class CursesMenu:
     def append_item(self, item: MenuItem) -> None:
         """Append an item to the list of items."""
         self.items.append(item)
+
+    def __repr__(self) -> str:
+        """Get a string representation of the menu."""
+        return f"<{self.title}: {self.subtitle}. {len(self.items)} items>"
